==> xom_1.1.orig.tar.gz: xom_1.1.orig/src/nu/xom/samples/DocumentMerger.java <==
/* Copyright 2002, 2003 Elliotte Rusty Harold
   
   This library is free software; you can redistribute it and/or modify
   it under the terms of version 2.1 of the GNU Lesser General Public 
   License as published by the Free Software Foundation.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
   GNU Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the 
   Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
   Boston, MA 02111-1307  USA
   
   You can contact Elliotte Rusty Harold by sending e-mail to
   elharo@metalab.unc.edu. Please include the word "XOM" in the
   subject line. The XOM home page is located at http://www.xom.nu/
*/

package nu.xom.samples;

import java.io.IOException;

import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.ParsingException;

/**
 *
 * <p>
 * Demonstrates parsing a document and reserializing it
 * so as to resolve all entity references.
 * </p>
 * 
 * @author Elliotte Rusty Harold
 * @version 1.0
 *
 */
public class DocumentMerger {

    public static void main(String[] args) {
        
        Builder builder = new Builder();
        try {
            Document doc = builder.build(args[0]);
            System.out.println(doc.toXML());
        }
        catch (IOException ex) {
            System.err.println(ex);
        }    
        catch (ParsingException ex) {
            System.err.println(ex);
        }        
        
    }
    
}

==> xom_1.3.8.orig.tar.gz: xom-1.3.8/src/nu/xom/samples/DocumentMerger.java <==
/* Copyright 2002, 2003 Elliotte Rusty Harold
   
   This library is free software; you can redistribute it and/or modify
   it under the terms of version 2.1 of the GNU Lesser General Public 
   License as published by the Free Software Foundation.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
   GNU Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the 
   Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
   Boston, MA 02111-1307  USA
   
   You can contact Elliotte Rusty Harold by sending e-mail to
   elharo@ibiblio.org. Please include the word "XOM" in the
   subject line. The XOM home page is located at https://xom.nu/
*/

package nu.xom.samples;

import java.io.IOException;

import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.ParsingException;

/**
 *
 * <p>
 * Demonstrates parsing a document and reserializing it
 * so as to resolve all entity references.
 * </p>
 * 
 * @author Elliotte Rusty Harold
 * @version 1.0
 *
 */
public class DocumentMerger {

    public static void main(String[] args) {
        
        Builder builder = new Builder();
        try {
            Document doc = builder.build(args[0]);
            System.out.println(doc.toXML());
        }
        catch (IOException ex) {
            System.err.println(ex);
        }    
        catch (ParsingException ex) {
            System.err.println(ex);
        }        
        
    }
    
}
